@@ -25,9 +25,7 @@ class ProspectorProfile:
         self.output_format = profile_dict.get("output-format")
         self.output_target = profile_dict.get("output-target")
         self.autodetect = profile_dict.get("autodetect", True)
-        self.uses = [
-            uses for uses in _ensure_list(profile_dict.get("uses", [])) if uses in ("django", "celery", "flask")
-        ]
+        self.uses = [uses for uses in _ensure_list(profile_dict.get("uses", [])) if uses in ("django", "celery")]
         self.max_line_length = profile_dict.get("max-line-length")
 
         # informational shorthands
@@ -133,7 +131,10 @@ def _load_content_package(name: str) -> Optional[dict[str, Any]]:
     used_name = None
     for file_name in file_names:
         used_name = f"{module_name}:{file_name}"
-        data = pkgutil.get_data(module_name, file_name)
+        try:
+            data = pkgutil.get_data(module_name, file_name)
+        except (ModuleNotFoundError, FileNotFoundError):
+            continue
         if data is not None:
             break
 
